@@ -15,6 +15,7 @@ class ChartMixin(ABC):
     title = None
     legend = False
     type_chart = None
+    _colors = None
 
     @abstractmethod
     def generate_dataset(self):
@@ -32,6 +33,17 @@ class ChartMixin(ABC):
             },
         }
 
+    def _generate_colors(self, labels):
+        return [
+            "#{:02x}{:02x}{:02x}".format(
+                *map(lambda x: random.randint(0, 255), range(3))
+            )
+            for entry in labels
+        ]
+
+    def set_colors(self, colors):
+        self._colors = colors
+
     def _get_color(self):
         return "#{:02x}{:02x}{:02x}".format(
             *map(lambda x: random.randint(0, 255), range(3))
@@ -41,12 +53,13 @@ class ChartMixin(ABC):
         color = color.lstrip("#")
         rgb = [int(color[i : i + 2], 16) for i in [0, 2, 4]]
 
-        return "rgba({},{},{},0.4)".format(*map(lambda x: x, rgb))
+        return "rgba({},{},{},0.6)".format(*map(lambda x: x, rgb))
 
 
 class BarChart(ChartMixin):
 
     type_chart = "bar"
+    tooltips = []
 
     def generate_options(self):
         options = super().generate_options()
@@ -60,18 +73,15 @@ class BarChart(ChartMixin):
         }
         return options
 
-    def generate_dataset(self, labels, data, dataLabel=None):
+    def generate_dataset(self, labels, data, dataLabel=""):
         dataset = {
             "labels": list(labels),
             "datasets": [
                 {
-                    "label": dataLabel if dataLabel is not None else "",
-                    "backgroundColor": [
-                        "#{:02x}{:02x}{:02x}".format(
-                            *map(lambda x: random.randint(0, 255), range(3))
-                        )
-                        for entry in labels
-                    ],
+                    "label": self.tooltips if len(self.tooltips) > 0 else dataLabel,
+                    "backgroundColor": self._colors
+                    if self._colors is not None
+                    else self._generate_colors(labels),
                     "data": list(data),
                 }
             ],
@@ -106,12 +116,9 @@ class HorizontalBarChart(ChartMixin):
             "datasets": [
                 {
                     "label": dataLabel if dataLabel is not None else "",
-                    "backgroundColor": [
-                        "#{:02x}{:02x}{:02x}".format(
-                            *map(lambda x: random.randint(0, 255), range(3))
-                        )
-                        for entry in labels
-                    ],
+                    "backgroundColor": self._colors
+                    if self._colors is not None
+                    else self._generate_colors(labels),
                     "data": list(data),
                 }
             ],
@@ -138,12 +145,9 @@ class PieChart(ChartMixin):
             "datasets": [
                 {
                     "label": dataLabel if dataLabel is not None else "",
-                    "backgroundColor": [
-                        "#{:02x}{:02x}{:02x}".format(
-                            *map(lambda x: random.randint(0, 255), range(3))
-                        )
-                        for entry in labels
-                    ],
+                    "backgroundColor": self._colors
+                    if self._colors is not None
+                    else self._generate_colors(labels),
                     "data": list(data),
                 }
             ],
@@ -165,7 +169,7 @@ class PolarAreaChart(PieChart):
 
 
 class LineChart(ChartMixin):
-    
+
     type_chart = "line"
 
     def create_node(self, data, label, fill=False, color=None):
@@ -205,11 +209,7 @@ class GroupChart(ChartMixin):
 
     def create_node(self, data, label, color=None):
         colorData = color if color is not None else self._get_color()
-        return {
-            "label": label,
-            "backgroundColor": colorData,
-            "data": list(data),
-        }
+        return {"label": label, "backgroundColor": colorData, "data": list(data)}
 
     def generate_dataset(self, labels, data):
         dataset = {"labels": list(labels), "datasets": list(data)}
@@ -237,7 +237,6 @@ class RadarChart(ChartMixin):
             "data": list(data),
         }
 
-
     def generate_dataset(self, labels, data):
         dataset = {"labels": list(labels), "datasets": list(data)}
 
